@@ -2,8 +2,8 @@
 #
 # sim.geno.R
 #
-# copyright (c) 2001-6, Karl W Broman
-# last modified Oct, 2006
+# copyright (c) 2001-7, Karl W Broman
+# last modified Sep, 2007
 # first written Feb, 2001
 # Licensed under the GNU General Public License version 2 (June, 1991)
 # 
@@ -23,6 +23,9 @@ function(cross, n.draws=16, step=0, off.end=0, error.prob=0.0001,
          map.function=c("haldane","kosambi","c-f","morgan"),
          stepwidth=c("fixed", "variable"))
 {
+  if(!any(class(cross) == "cross"))
+    stop("Input should have class \"cross\".")
+
   # map function
   map.function <- match.arg(map.function)
   if(map.function=="kosambi") mf <- mf.k
